pub enum GameEventDeliveryMode {
Unspecified,
ByDistance,
}Expand description
Controls when a listener receives an event during dispatch.
Variants
Unspecified
Handle the event immediately while scanning listeners.
ByDistance
Queue the event and handle it after sorting by source distance.